@@ -10,7 +10,7 @@ def search(
     query: Q = None,
     sources: List = [],
     highlight: Dict = {},
-    sort: str = None
+    sort: str = None,
     extras: Dict = {}
 ):
 
